==> mx-tools_21.8.02.tar.xz: mx-tools-21.8.02/translations/mx-tools_kk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="kk">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="411"/>
        <source>MX Tools</source>
        <translation type="unfinished">MX саймандары</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="53"/>
        <source>About this application</source>
        <translation type="unfinished">Бұл қолданба жөнінде</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="56"/>
        <source>About...</source>
        <translation type="unfinished">Осы туралы...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="63"/>
        <source>Alt+B</source>
        <translation type="unfinished">Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="127"/>
        <source>Close application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="130"/>
        <source>Close</source>
        <translation type="unfinished">Жабу</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="137"/>
        <source>Alt+N</source>
        <translation type="unfinished">Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="165"/>
        <source>Manual</source>
        <translation type="unfinished">Нұсқаулық</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="263"/>
        <source>These MX applications save time and effort with important tasks.</source>
        <translation type="unfinished">Бұл MX қолданбалары маңызды тапсырмаларды орындау кезінде уақытты үнемдейді.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="279"/>
        <source>Hide individual tools from the menu</source>
        <translation type="unfinished">Жеке-жеке саймандарды мәзірден жасыру</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="298"/>
        <source>search</source>
        <translation type="unfinished">іздеу</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="410"/>
        <source>About MX Tools</source>
        <translation type="unfinished">MX саймандары жөнінде</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="411"/>
        <source>Version: </source>
        <translation type="unfinished">Нұсқасы:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="413"/>
        <source>Configuration Tools for MX Linux</source>
        <translation type="unfinished">MX Linux үшін баптау саймандары</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="414"/>
        <source>Copyright (c) MX Linux</source>
        <translation type="unfinished">Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="415"/>
        <source>License</source>
        <translation type="unfinished">Лицензиясы</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="416"/>
        <source>Changelog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="417"/>
        <source>Cancel</source>
        <translation type="unfinished">Бас тарту</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="432"/>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>mxtools</name>
    <message>
        <source>MX Tools</source>
        <translation type="vanished">MX саймандары</translation>
    </message>
    <message>
        <source>About this application</source>
        <translation type="vanished">Бұл қолданба жөнінде</translation>
    </message>
    <message>
        <source>About...</source>
        <translation type="vanished">Осы туралы...</translation>
    </message>
    <message>
        <source>Alt+B</source>
        <translation type="vanished">Alt+B</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Жабу</translation>
    </message>
    <message>
        <source>Alt+N</source>
        <translation type="vanished">Alt+N</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation type="vanished">Нұсқаулық</translation>
    </message>
    <message>
        <source>These MX applications save time and effort with important tasks.</source>
        <translation type="vanished">Бұл MX қолданбалары маңызды тапсырмаларды орындау кезінде уақытты үнемдейді.</translation>
    </message>
    <message>
        <source>Hide individual tools from the menu</source>
        <translation type="vanished">Жеке-жеке саймандарды мәзірден жасыру</translation>
    </message>
    <message>
        <source>search</source>
        <translation type="vanished">іздеу</translation>
    </message>
    <message>
        <source>About MX Tools</source>
        <translation type="vanished">MX саймандары жөнінде</translation>
    </message>
    <message>
        <source>Version: </source>
        <translation type="vanished">Нұсқасы:</translation>
    </message>
    <message>
        <source>Configuration Tools for MX Linux</source>
        <translation type="vanished">MX Linux үшін баптау саймандары</translation>
    </message>
    <message>
        <source>Copyright (c) MX Linux</source>
        <translation type="vanished">Copyright (c) MX Linux</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Лицензиясы</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Бас тарту</translation>
    </message>
</context>
</TS>

==> mx-tools_23.7.01.tar.xz: mx-tools-23.7.01/translations/mx-tools_kk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="kk">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="411"/>
        <source>MX Tools</source>
        <translation>MX саймандары</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="53"/>
        <source>About this application</source>
        <translation>Бұл қолданба жөнінде</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="56"/>
        <source>About...</source>
        <translation>Осы туралы...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="63"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="127"/>
        <source>Close application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="130"/>
        <source>Close</source>
        <translation>Жабу</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="137"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="165"/>
        <source>Manual</source>
        <translation>Нұсқаулық</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="274"/>
        <source>These MX applications save time and effort with important tasks.</source>
        <translation>Бұл MX қолданбалары маңызды тапсырмаларды орындау кезінде уақытты үнемдейді.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="290"/>
        <source>Hide individual tools from the menu</source>
        <translation>Жеке-жеке саймандарды мәзірден жасыру</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="309"/>
        <source>search</source>
        <translation>іздеу</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="410"/>
        <source>About MX Tools</source>
        <translation>MX саймандары жөнінде</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="411"/>
        <source>Version: </source>
        <translation>Нұсқасы:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="412"/>
        <source>Configuration Tools for MX Linux</source>
        <translation>MX Linux үшін баптау саймандары</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="415"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="416"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="40"/>
        <source>License</source>
        <translation>Лицензиясы</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="41"/>
        <location filename="../about.cpp" line="51"/>
        <source>Changelog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Cancel</source>
        <translation>Бас тарту</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="64"/>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
